==> rn-hidoop-ui-lib-0.1.13.tgz: package/src/Components/Molecules/Card/ItemRowCart.js <==
import { View, StyleSheet, Image, TouchableOpacity } from 'react-native';
import React from 'react';
import { colors, width } from '../../../constant/theme';
import { QtyButton } from '../Button';
import { Icon, Text } from '../../Atoms';
import { formatMoney } from '../../../helpers';

const ItemRowCart = ({
  item,
  style,
  onQtyUpdate,
  onPressTrash,
  editable = true,
  isLastItem,
}) => {
  return (
    <View style={[styles.productListItem, style]}>
      <View style={{ flex: 1.5 }}>
        <Image
          source={{ uri: item?.image_url }}
          style={styles.productListImage}
          resizeMode="contain"
        />
      </View>
      <View style={[styles.rightContentItem, isLastItem ? {} : styles.item]}>
        <View style={styles.productListData}>
          <Text text={item?.item_name} color={colors.grey.grey8} />
          {editable ? (
            <View style={styles.productListDataDetail}>
              <QtyButton initQty={item?.qty} onValueChange={onQtyUpdate} />
              <View style={styles.verticalLine} />
              <TouchableOpacity onPress={onPressTrash}>
                <Icon name="trash-1" color={colors.error} size={20} />
              </TouchableOpacity>
            </View>
          ) : (
            <View style={styles.productListDataDetail}>
              <Text
                text={`${item?.qty} produk`}
                textStyle={{ paddingVertical: width * 0.04 }}
              />
            </View>
          )}
        </View>
        <View style={styles.priceWrapper}>
          <Text
            text={formatMoney(item?.price)}
            textStyle={styles.itemPrice}
            variant="bold"
            color={colors.grey.black}
          />
        </View>
      </View>
    </View>
  );
};

const styles = StyleSheet.create({
  productListItem: {
    flex: 1,
    flexDirection: 'row',
    alignItems: 'flex-start',
    justifyContent: 'space-between',
    marginBottom: width * 0.03,
  },
  productListImage: {
    width: width * 0.13,
    height: width * 0.13,
    aspectRatio: 1,
    borderRadius: width * 0.08,
  },
  rightContentItem: {
    flex: 7,
    flexDirection: 'row',
    justifyContent: 'space-between',
  },
  item: {
    borderBottomWidth: 0.5,
    borderBottomColor: colors.grey.grey8,
  },
  productListData: {
    flex: 6,
    paddingHorizontal: width * 0.03,
  },
  productListDataDetail: {
    width: '80%',
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
    marginTop: width * 0.01,
  },
  priceWrapper: {
    flex: 2,
    alignItems: 'flex-end',
    justifyContent: 'flex-end',
  },
  verticalLine: {
    borderLeftWidth: 1,
    borderLeftColor: colors.grey.soft,
    marginHorizontal: width * 0.01,
    width: 1,
    height: '50%',
  },
  itemPrice: {
    textAlign: 'center',
    textAlignVertical: 'bottom',
    paddingBottom: width * 0.04,
  },
});

export default ItemRowCart;

==> rn-hidoop-ui-lib-0.1.16.tgz: package/src/Components/Molecules/Card/ItemRowCart.js <==
import { View, StyleSheet, Image, TouchableOpacity } from 'react-native';
import React from 'react';
import { colors, width } from '../../../constant/theme';
import { QtyButton } from '../Button';
import { Icon, Text } from '../../Atoms';
import { formatMoney } from '../../../helpers';

const ItemRowCart = ({
  item,
  style,
  onQtyUpdate,
  onPressTrash,
  editable = true,
  isLastItem,
}) => {
  return (
    <View style={[styles.productListItem, style]}>
      <View style={{ flex: 1.5 }}>
        <Image
          source={{ uri: item?.image_url }}
          style={styles.productListImage}
          resizeMode="contain"
        />
      </View>
      <View style={[styles.rightContentItem, isLastItem ? {} : styles.item]}>
        <View style={styles.productListData}>
          <Text text={item?.item_name} color={colors.grey.grey8} />
          {editable ? (
            <View style={styles.productListDataDetail}>
              <QtyButton initQty={item?.qty} onValueChange={onQtyUpdate} />
              <View style={styles.verticalLine} />
              <TouchableOpacity onPress={onPressTrash}>
                <Icon name="trash-1" color={colors.error} size={20} />
              </TouchableOpacity>
            </View>
          ) : (
            <View style={styles.productListDataDetail}>
              <Text
                text={`${item?.qty || 1} produk`}
                textStyle={{ paddingVertical: width * 0.04 }}
              />
            </View>
          )}
        </View>
        <View style={styles.priceWrapper}>
          <Text
            text={formatMoney(item?.price)}
            textStyle={styles.itemPrice}
            variant="bold"
            color={colors.grey.black}
          />
        </View>
      </View>
    </View>
  );
};

const styles = StyleSheet.create({
  productListItem: {
    flex: 1,
    flexDirection: 'row',
    alignItems: 'flex-start',
    justifyContent: 'space-between',
    marginBottom: width * 0.03,
  },
  productListImage: {
    width: width * 0.13,
    height: width * 0.13,
    aspectRatio: 1,
    borderRadius: width * 0.08,
  },
  rightContentItem: {
    flex: 7,
    flexDirection: 'row',
    justifyContent: 'space-between',
  },
  item: {
    borderBottomWidth: 0.5,
    borderBottomColor: colors.grey.grey8,
  },
  productListData: {
    flex: 6,
    paddingHorizontal: width * 0.03,
  },
  productListDataDetail: {
    width: '80%',
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
    marginTop: width * 0.01,
  },
  priceWrapper: {
    flex: 2,
    alignItems: 'flex-end',
    justifyContent: 'flex-end',
  },
  verticalLine: {
    borderLeftWidth: 1,
    borderLeftColor: colors.grey.soft,
    marginHorizontal: width * 0.01,
    width: 1,
    height: '50%',
  },
  itemPrice: {
    textAlign: 'center',
    textAlignVertical: 'bottom',
    paddingBottom: width * 0.04,
  },
});

export default ItemRowCart;
